import { ContainerBuilder } from "@tmorin/ceb-inversion-core";
/**
 * An abstract class helping to implement a {@link TestSuiteExecutor}.
 *
 * The abstraction expects the following execution steps:
 *
 * 1. {@link AbstractTestSuiteExecutor.before}: prepare the test suite, optional
 * 2. {@link AbstractTestSuiteExecutor.provider} : provide the {@link ContainerBuilder}, optional
 * 3. {@link AbstractTestSuiteExecutor.configure} : configure the {@link Container}, optional
 * 4. {@link AbstractTestSuiteExecutor.execute}: execute the test suite
 * 5. {@link AbstractTestSuiteExecutor.after}: cleanup the test suite, optional
 */
export class AbstractTestSuiteExecutor {
    constructor(suite, before, provide = () => ContainerBuilder.get(), configure, after) {
        this.suite = suite;
        this.before = before;
        this.provide = provide;
        this.configure = configure;
        this.after = after;
    }
}
/**
 * An abstract class helping to implement builder of {@link TestSuiteExecutor} based on {@link AbstractTestSuiteExecutor}.
 */
export class AbstractTestSuiteExecutorBuilder {
    constructor(_suite, _provider, _configurer, _before, _after) {
        this._suite = _suite;
        this._provider = _provider;
        this._configurer = _configurer;
        this._before = _before;
        this._after = _after;
    }
    /**
     * Define the before method.
     * @param cb the callback
     */
    before(cb) {
        this._before = cb;
        return this;
    }
    /**
     * Define the provider of {@link ContainerBuilder}.
     * @param provider the provider
     */
    provide(provider) {
        this._provider = provider;
        return this;
    }
    /**
     * Define the configurer of {@link Container}
     * @param cb the callback
     */
    configure(cb) {
        this._configurer = cb;
        return this;
    }
    /**
     * Define the after method.
     * @param cb the callback
     */
    after(cb) {
        this._after = cb;
        return this;
    }
    /**
     * Build and then execute the {@link TestSuiteExecutor}.
     */
    test() {
        return this.build().execute();
    }
}
//# sourceMappingURL=executor.js.map