import { Callback, CallbackWithContainerBuilder, ContainerBuilderProvider } from "./common";
import { TestSuite } from "./suite";
/**
 * An executor of test suite.
 */
export interface TestSuiteExecutor<O = any> {
    /**
     * The test suite.
     */
    readonly suite: TestSuite;
    /**
     * Execute the test suite.
     */
    execute(): O;
}
/**
 * An abstract class helping to implement a {@link TestSuiteExecutor}.
 *
 * The abstraction expects the following execution steps:
 *
 * 1. {@link AbstractTestSuiteExecutor.before}: prepare the test suite, optional
 * 2. {@link AbstractTestSuiteExecutor.provider} : provide the {@link ContainerBuilder}, optional
 * 3. {@link AbstractTestSuiteExecutor.configure} : configure the {@link Container}, optional
 * 4. {@link AbstractTestSuiteExecutor.execute}: execute the test suite
 * 5. {@link AbstractTestSuiteExecutor.after}: cleanup the test suite, optional
 */
export declare abstract class AbstractTestSuiteExecutor<O = any> implements TestSuiteExecutor<O> {
    readonly suite: TestSuite;
    protected before?: Callback | undefined;
    protected provide: ContainerBuilderProvider;
    protected configure?: CallbackWithContainerBuilder | undefined;
    protected after?: Callback | undefined;
    protected constructor(suite: TestSuite, before?: Callback | undefined, provide?: ContainerBuilderProvider, configure?: CallbackWithContainerBuilder | undefined, after?: Callback | undefined);
    /**
     * Execute the test suite.
     */
    abstract execute(): O;
}
/**
 * An abstract class helping to implement builder of {@link TestSuiteExecutor} based on {@link AbstractTestSuiteExecutor}.
 */
export declare abstract class AbstractTestSuiteExecutorBuilder<O = any> {
    protected _suite: TestSuite;
    protected _provider?: ContainerBuilderProvider | undefined;
    protected _configurer?: CallbackWithContainerBuilder | undefined;
    protected _before?: Callback | undefined;
    protected _after?: Callback | undefined;
    protected constructor(_suite: TestSuite, _provider?: ContainerBuilderProvider | undefined, _configurer?: CallbackWithContainerBuilder | undefined, _before?: Callback | undefined, _after?: Callback | undefined);
    /**
     * Define the before method.
     * @param cb the callback
     */
    before(cb: Callback): this;
    /**
     * Define the provider of {@link ContainerBuilder}.
     * @param provider the provider
     */
    provide(provider: ContainerBuilderProvider): this;
    /**
     * Define the configurer of {@link Container}
     * @param cb the callback
     */
    configure(cb: CallbackWithContainerBuilder): this;
    /**
     * Define the after method.
     * @param cb the callback
     */
    after(cb: Callback): this;
    /**
     * Build a {@link TestSuiteExecutor}.
     */
    abstract build(): TestSuiteExecutor<O>;
    /**
     * Build and then execute the {@link TestSuiteExecutor}.
     */
    test(): O;
}
